==> CTADIRAC-2.0a9.tar.gz: CTADIRAC-2.0a9/src/CTADIRAC/Core/scripts/cta_user_managedata.py <==
#!/usr/bin/env python
""" Simple data management script for users
    put and register files in DFC
"""

__RCSID__ = "$Id$"

# generic imports
import os
import glob
import json

# DIRAC imports
import DIRAC
from DIRAC.Core.Base import Script
Script.parseCommandLine()

# Specific DIRAC imports
from DIRAC.Core.Utilities import List
from CTADIRAC.Core.Workflow.Modules.ProdDataManager import ProdDataManager

####################################################


def putAndRegisterPROD3(args):
  """ simple wrapper to put and register all analysis files

  Keyword arguments:
  args -- a list of arguments in order []
  """
  outputpattern = args[0]
  outputpath = args[1]
  SEListArg = json.loads(args[2])
  SEList = []
  for SE in SEListArg:
    SEList.append(str(SE))

  # # Init DataManager
  catalogs = ['DIRACFileCatalog']
  prod3dm = ProdDataManager(catalogs)

  # # Upload data files
  res = prod3dm._checkemptydir(outputpattern)
  if not res['OK']:
    return res

  for localfile in glob.glob(outputpattern):
    filename = os.path.basename(localfile)
    lfn = os.path.join(outputpath, filename)
    SEList = List.randomize(SEList)
    res = prod3dm._putAndRegisterToSEList(lfn, localfile, SEList)
    # ##  check if failed
    if not res['OK']:
      return res

  return DIRAC.S_OK()


####################################################
if __name__ == '__main__':
  args = Script.getPositionalArgs()
  try:
    res = putAndRegisterPROD3(args)
    if not res['OK']:
      DIRAC.gLogger.error(res['Message'])
      DIRAC.exit(-1)
    else:
      DIRAC.gLogger.notice('Done')
  except Exception:
    DIRAC.gLogger.exception()
    DIRAC.exit(-1)

==> CTADIRAC-2.2.1.tar.gz: CTADIRAC-2.2.1/src/CTADIRAC/Core/scripts/cta_user_managedata.py <==
#!/usr/bin/env python
""" Simple data management script for users
    put and register files in DFC or the specified catalog
"""

__RCSID__ = "$Id$"

# generic imports
import os
import glob
import json

# DIRAC imports
import DIRAC
from DIRAC.Core.Utilities.DIRACScript import DIRACScript as Script
Script.parseCommandLine()

# Specific DIRAC imports
from DIRAC.Core.Utilities import List
from CTADIRAC.Core.Workflow.Modules.ProdDataManager import ProdDataManager

####################################################

@Script()
def main():
  """ simple wrapper to put and register all analysis files

  Keyword arguments:
  args -- a list of arguments in order []
  """
  args = Script.getPositionalArgs()
  outputpattern = args[0]
  outputpath = args[1]
  SEListArg = json.loads(args[2])
  SEList = []
  for SE in SEListArg:
    SEList.append(str(SE))
  # Load catalogs
  catalogs = args[3]
  catalogs_json = json.loads(catalogs)

  # # Init DataManager
  prod_dm = ProdDataManager(catalogs_json)

  # # Upload data files
  res = prod_dm._checkemptydir(outputpattern)
  if not res['OK']:
    return res

  for localfile in glob.glob(outputpattern):
    filename = os.path.basename(localfile)
    lfn = os.path.join(outputpath, filename)
    SEList = List.randomize(SEList)
    res = prod_dm._putAndRegisterToSEList(lfn, localfile, SEList)
    # ##  check if failed
    if not res['OK']:
      return res

  DIRAC.exit()


####################################################
if __name__ == '__main__':
  main()
